pub struct Github<'a> { /* private fields */ }Expand description
The Github repository and the Url to the files in the repository.
Implementations
Sourceimpl<'a> Github<'a>
impl<'a> Github<'a>
Sourcepub fn new(
owner: &'a str,
repo: &'a str,
branch: &'a str,
path: &'a str,
file: &'a str,
) -> Github<'a>
pub fn new( owner: &'a str, repo: &'a str, branch: &'a str, path: &'a str, file: &'a str, ) -> Github<'a>
Creates a new instance with empty strings.
Sourcepub fn build_url(&mut self)
pub fn build_url(&mut self)
Builds the Url for the raw contents of a file.
This function should only be used for files on Github which can be opened in raw format.
Usage
let mut github_repo = Github::new("OneilNvM", "rl-hours-tracker", "master", "src", "main.rs");
// Example Output: "https://raw.githubusercontent.com/OneilNvM/rl-hours-tracker/refs/heads/master/src/main.rs"
github_repo.build_url();Sourcepub fn build_image_url(&mut self)
pub fn build_image_url(&mut self)
Builds the Url for the blob of an image file.
This function should only be used for image files in a Github repository.
Usage
let mut github_repo = Github::new("OneilNvM", "rl-hours-tracker", "master", "images", "img.png");
// Example Output: "https://github.com/OneilNvM/rl-hours-tracker/blob/master/images/img.png"
github_repo.build_image_url();Trait Implementations