pub fn date_binary_search(split_newline: &Vec<&str>, c_date: &String) -> usizeExpand description
This function is used to perform a binary search on a Vec<&str> Vector and compares the dates in the Vector with
the c_date String. The function then returns a usize for the index of the date, or a usize::MAX if the
date is not present.