pub struct Github<'a> {
pub owner: &'a str,
pub repo: &'a str,
pub branch: &'a str,
pub path: &'a str,
pub file: &'a str,
pub url: String,
}Expand description
The Github repository and the Url to the files in the repository.
Fields
owner: &'a strrepo: &'a strbranch: &'a strpath: &'a strfile: &'a strurl: StringImplementations
sourceimpl<'a> Github<'a>
impl<'a> Github<'a>
sourcepub fn set_fields(
&mut self,
owner: &'a str,
repo: &'a str,
branch: &'a str,
path: &'a str,
file: &'a str,
)
pub fn set_fields( &mut self, owner: &'a str, repo: &'a str, branch: &'a str, path: &'a str, file: &'a str, )
This sets the fields of the Github instance.
The fields need to be set in order to create a valid Url when using Github::build_url or Github::build_image_url
Usage
let mut github_repo = Github::new();
github_repo.set_fields("OneilNvM", "rl-hours-tracker", "master", "src", "main.rs");sourcepub fn build_url(&mut self)
pub fn build_url(&mut self)
Builds the Url for the raw contents of a file.
This function should only be used for files on Github which can be opened in raw format.
Fields need to be set first through Github::set_fields.
Usage
let mut github_repo = Github::new();
github_repo.set_fields(owner, repo, branch, path, file);
// Example Output: "https://raw.githubusercontent.com/OneilNvM/rl-hours-tracker/refs/heads/master/src/main.rs"
github_repo.build_url();sourcepub fn build_image_url(&mut self)
pub fn build_image_url(&mut self)
Builds the Url for the blob of an image file.
This function should only be used for image files in a Github repository.
Fields need to be set first through Github::set_fields.
Usage
let mut github_repo = Github::new();
github_repo.set_fields(owner, repo, branch, path, file);
// Example Output: "https://github.com/OneilNvM/rl-hours-tracker/blob/master/images/img.png"
github_repo.build_image_url();Trait Implementations